@@ -13,9 +13,6 @@ function(p)
   cat(paste("Number of Hops N:  ",length(p)),"\n")
   cat(paste("Probabilities:     ", paste(p, collapse=", ")),"\n")
   cat("   ","\n")
-  cat("#######","\n")
-  cat("Results","\n")
-  cat("#######","\n")
   out2 = expected(p)
   cat("   ","\n")
   print(out2)
